from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.v2025_r0.hub_collaborations_v2025_r0 import (
    HubCollaborationsV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.client_error_v2025_r0 import ClientErrorV2025R0

from box_sdk_gen.parameters.v2025_r0.box_version_header_v2025_r0 import (
    BoxVersionHeaderV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.hub_collaboration_v2025_r0 import (
    HubCollaborationV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.hub_collaboration_create_request_v2025_r0 import (
    HubCollaborationCreateRequestV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.hub_collaboration_update_request_v2025_r0 import (
    HubCollaborationUpdateRequestV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class CreateHubCollaborationV2025R0HubTypeField(str, Enum):
    HUBS = 'hubs'


class CreateHubCollaborationV2025R0Hub(BaseObject):
    _discriminator = 'type', {'hubs'}

    def __init__(
        self,
        id: str,
        *,
        type: CreateHubCollaborationV2025R0HubTypeField = CreateHubCollaborationV2025R0HubTypeField.HUBS,
        **kwargs
    ):
        """
        :param id: ID of the object.
        :type id: str
        :param type: The value will always be `hubs`., defaults to CreateHubCollaborationV2025R0HubTypeField.HUBS
        :type type: CreateHubCollaborationV2025R0HubTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class CreateHubCollaborationV2025R0AccessibleBy(BaseObject):
    def __init__(
        self,
        type: str,
        *,
        id: Optional[str] = None,
        login: Optional[str] = None,
        **kwargs
    ):
        """
                :param type: The type of collaborator to invite.
        Possible values are `user` or `group`.
                :type type: str
                :param id: The ID of the user or group.

        Alternatively, use `login` to specify a user by email
        address., defaults to None
                :type id: Optional[str], optional
                :param login: The email address of the user who gets access to the item.

        Alternatively, use `id` to specify a user by user ID., defaults to None
                :type login: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id
        self.login = login


class HubCollaborationsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_hub_collaborations_v2025_r0(
        self,
        hub_id: str,
        *,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> HubCollaborationsV2025R0:
        """
                Retrieves all collaborations for a Box Hub.
                :param hub_id: The unique identifier that represent a hub.

        The ID for any hub can be determined
        by visiting this hub in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/hubs/123`
        the `hub_id` is `123`.
                :type hub_id: str
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'hub_id': to_string(hub_id),
                'marker': to_string(marker),
                'limit': to_string(limit),
            }
        )
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/hub_collaborations']
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, HubCollaborationsV2025R0)

    def create_hub_collaboration_v2025_r0(
        self,
        hub: CreateHubCollaborationV2025R0Hub,
        accessible_by: CreateHubCollaborationV2025R0AccessibleBy,
        role: str,
        *,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> HubCollaborationV2025R0:
        """
                Adds a collaboration for a single user or a single group to a Box Hub.

                Collaborations can be created using email address, user IDs, or group IDs.

                :param hub: Box Hubs reference.
                :type hub: CreateHubCollaborationV2025R0Hub
                :param accessible_by: The user or group who gets access to the item.
                :type accessible_by: CreateHubCollaborationV2025R0AccessibleBy
                :param role: The level of access granted to a Box Hub.
        Possible values are `editor`, `viewer`, and `co-owner`.
                :type role: str
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'hub': hub, 'accessible_by': accessible_by, 'role': role}
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/hub_collaborations']
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, HubCollaborationV2025R0)

    def get_hub_collaboration_by_id_v2025_r0(
        self,
        hub_collaboration_id: str,
        *,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> HubCollaborationV2025R0:
        """
                Retrieves details for a Box Hub collaboration by collaboration ID.
                :param hub_collaboration_id: The ID of the hub collaboration.
        Example: "1234"
                :type hub_collaboration_id: str
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/hub_collaborations/',
                        to_string(hub_collaboration_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, HubCollaborationV2025R0)

    def update_hub_collaboration_by_id_v2025_r0(
        self,
        hub_collaboration_id: str,
        *,
        role: Optional[str] = None,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> HubCollaborationV2025R0:
        """
                Updates a Box Hub collaboration.

                Can be used to change the Box Hub role.

                :param hub_collaboration_id: The ID of the hub collaboration.
        Example: "1234"
                :type hub_collaboration_id: str
                :param role: The level of access granted to a Box Hub.
        Possible values are `editor`, `viewer`, and `co-owner`., defaults to None
                :type role: Optional[str], optional
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'role': role}
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/hub_collaborations/',
                        to_string(hub_collaboration_id),
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, HubCollaborationV2025R0)

    def delete_hub_collaboration_by_id_v2025_r0(
        self,
        hub_collaboration_id: str,
        *,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Deletes a single Box Hub collaboration.
                :param hub_collaboration_id: The ID of the hub collaboration.
        Example: "1234"
                :type hub_collaboration_id: str
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/hub_collaborations/',
                        to_string(hub_collaboration_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class LegalHoldPolicyMiniTypeField(str, Enum):
    LEGAL_HOLD_POLICY = 'legal_hold_policy'


class LegalHoldPolicyMini(BaseObject):
    _discriminator = 'type', {'legal_hold_policy'}

    def __init__(
        self,
        id: str,
        *,
        type: LegalHoldPolicyMiniTypeField = LegalHoldPolicyMiniTypeField.LEGAL_HOLD_POLICY,
        **kwargs
    ):
        """
        :param id: The unique identifier for this legal hold policy.
        :type id: str
        :param type: The value will always be `legal_hold_policy`., defaults to LegalHoldPolicyMiniTypeField.LEGAL_HOLD_POLICY
        :type type: LegalHoldPolicyMiniTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type



from enum import Enum

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.shield_information_barrier import ShieldInformationBarrier

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.shield_information_barriers import ShieldInformationBarriers

from box_sdk_gen.schemas.enterprise_base import EnterpriseBase

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class UpdateShieldInformationBarrierStatusStatus(str, Enum):
    PENDING = 'pending'
    DISABLED = 'disabled'


class ShieldInformationBarriersManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_shield_information_barrier_by_id(
        self,
        shield_information_barrier_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> ShieldInformationBarrier:
        """
                Get shield information barrier based on provided ID.
                :param shield_information_barrier_id: The ID of the shield information barrier.
        Example: "1910967"
                :type shield_information_barrier_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/shield_information_barriers/',
                        to_string(shield_information_barrier_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, ShieldInformationBarrier)

    def update_shield_information_barrier_status(
        self,
        id: str,
        status: UpdateShieldInformationBarrierStatusStatus,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> ShieldInformationBarrier:
        """
        Change status of shield information barrier with the specified ID.
        :param id: The ID of the shield information barrier.
        :type id: str
        :param status: The desired status for the shield information barrier.
        :type status: UpdateShieldInformationBarrierStatusStatus
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'id': id, 'status': status}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/shield_information_barriers/change_status',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, ShieldInformationBarrier)

    def get_shield_information_barriers(
        self,
        *,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> ShieldInformationBarriers:
        """
                Retrieves a list of shield information barrier objects

                for the enterprise of JWT.

                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'marker': to_string(marker), 'limit': to_string(limit)}
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/shield_information_barriers',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, ShieldInformationBarriers)

    def create_shield_information_barrier(
        self,
        enterprise: EnterpriseBase,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> ShieldInformationBarrier:
        """
        Creates a shield information barrier to

        separate individuals/groups within the same


        firm and prevents confidential information passing between them.

        :param enterprise: The `type` and `id` of enterprise this barrier is under.
        :type enterprise: EnterpriseBase
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'enterprise': enterprise}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/shield_information_barriers',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, ShieldInformationBarrier)



from typing import Optional

from box_sdk_gen.schemas.shield_information_barrier_segment_member_base import (
    ShieldInformationBarrierSegmentMemberBaseTypeField,
)

from box_sdk_gen.schemas.shield_information_barrier_segment_member_base import (
    ShieldInformationBarrierSegmentMemberBase,
)

from box_sdk_gen.schemas.user_base import UserBase

from box_sdk_gen.box.errors import BoxSDKError


class ShieldInformationBarrierSegmentMemberMini(
    ShieldInformationBarrierSegmentMemberBase
):
    def __init__(
        self,
        *,
        user: Optional[UserBase] = None,
        id: Optional[str] = None,
        type: Optional[ShieldInformationBarrierSegmentMemberBaseTypeField] = None,
        **kwargs
    ):
        """
                :param id: The unique identifier for the
        shield information barrier segment member., defaults to None
                :type id: Optional[str], optional
                :param type: The type of the shield information barrier segment member., defaults to None
                :type type: Optional[ShieldInformationBarrierSegmentMemberBaseTypeField], optional
        """
        super().__init__(id=id, type=type, **kwargs)
        self.user = user



from typing import Union

from box_sdk_gen.schemas.folder_mini import FolderMini

from box_sdk_gen.schemas.file_mini import FileMini

from box_sdk_gen.box.errors import BoxSDKError

Resource = Union[FolderMini, FileMini]



from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.sign_request_prefill_tag import SignRequestPrefillTag

from box_sdk_gen.box.errors import BoxSDKError


class SignRequestBase(BaseObject):
    def __init__(
        self,
        *,
        is_document_preparation_needed: Optional[bool] = None,
        redirect_url: Optional[str] = None,
        declined_redirect_url: Optional[str] = None,
        are_text_signatures_enabled: Optional[bool] = None,
        email_subject: Optional[str] = None,
        email_message: Optional[str] = None,
        are_reminders_enabled: Optional[bool] = None,
        name: Optional[str] = None,
        prefill_tags: Optional[List[SignRequestPrefillTag]] = None,
        days_valid: Optional[int] = None,
        external_id: Optional[str] = None,
        template_id: Optional[str] = None,
        external_system_name: Optional[str] = None,
        **kwargs
    ):
        """
        :param is_document_preparation_needed: Indicates if the sender should receive a `prepare_url` in the response to complete document preparation using the UI., defaults to None
        :type is_document_preparation_needed: Optional[bool], optional
        :param redirect_url: When specified, the signature request will be redirected to this url when a document is signed., defaults to None
        :type redirect_url: Optional[str], optional
        :param declined_redirect_url: The uri that a signer will be redirected to after declining to sign a document., defaults to None
        :type declined_redirect_url: Optional[str], optional
        :param are_text_signatures_enabled: Disables the usage of signatures generated by typing (text)., defaults to None
        :type are_text_signatures_enabled: Optional[bool], optional
        :param email_subject: Subject of sign request email. This is cleaned by sign request. If this field is not passed, a default subject will be used., defaults to None
        :type email_subject: Optional[str], optional
        :param email_message: Message to include in sign request email. The field is cleaned through sanitization of specific characters. However, some html tags are allowed. Links included in the message are also converted to hyperlinks in the email. The message may contain the following html tags including `a`, `abbr`, `acronym`, `b`, `blockquote`, `code`, `em`, `i`, `ul`, `li`, `ol`, and `strong`. Be aware that when the text to html ratio is too high, the email may end up in spam filters. Custom styles on these tags are not allowed. If this field is not passed, a default message will be used., defaults to None
        :type email_message: Optional[str], optional
        :param are_reminders_enabled: Reminds signers to sign a document on day 3, 8, 13 and 18. Reminders are only sent to outstanding signers., defaults to None
        :type are_reminders_enabled: Optional[bool], optional
        :param name: Name of the signature request., defaults to None
        :type name: Optional[str], optional
        :param prefill_tags: When a document contains sign-related tags in the content, you can prefill them using this `prefill_tags` by referencing the 'id' of the tag as the `external_id` field of the prefill tag., defaults to None
        :type prefill_tags: Optional[List[SignRequestPrefillTag]], optional
        :param days_valid: Set the number of days after which the created signature request will automatically expire if not completed. By default, we do not apply any expiration date on signature requests, and the signature request does not expire., defaults to None
        :type days_valid: Optional[int], optional
        :param external_id: This can be used to reference an ID in an external system that the sign request is related to., defaults to None
        :type external_id: Optional[str], optional
        :param template_id: When a signature request is created from a template this field will indicate the id of that template., defaults to None
        :type template_id: Optional[str], optional
        :param external_system_name: Used as an optional system name to appear in the signature log next to the signers who have been assigned the `embed_url_external_id`., defaults to None
        :type external_system_name: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.is_document_preparation_needed = is_document_preparation_needed
        self.redirect_url = redirect_url
        self.declined_redirect_url = declined_redirect_url
        self.are_text_signatures_enabled = are_text_signatures_enabled
        self.email_subject = email_subject
        self.email_message = email_message
        self.are_reminders_enabled = are_reminders_enabled
        self.name = name
        self.prefill_tags = prefill_tags
        self.days_valid = days_valid
        self.external_id = external_id
        self.template_id = template_id
        self.external_system_name = external_system_name



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.file_mini import FileMini

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class TaskAssignmentTypeField(str, Enum):
    TASK_ASSIGNMENT = 'task_assignment'


class TaskAssignmentResolutionStateField(str, Enum):
    COMPLETED = 'completed'
    INCOMPLETE = 'incomplete'
    APPROVED = 'approved'
    REJECTED = 'rejected'


class TaskAssignment(BaseObject):
    _discriminator = 'type', {'task_assignment'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[TaskAssignmentTypeField] = None,
        item: Optional[FileMini] = None,
        assigned_to: Optional[UserMini] = None,
        message: Optional[str] = None,
        completed_at: Optional[DateTime] = None,
        assigned_at: Optional[DateTime] = None,
        reminded_at: Optional[DateTime] = None,
        resolution_state: Optional[TaskAssignmentResolutionStateField] = None,
        assigned_by: Optional[UserMini] = None,
        **kwargs
    ):
        """
                :param id: The unique identifier for this task assignment., defaults to None
                :type id: Optional[str], optional
                :param type: The value will always be `task_assignment`., defaults to None
                :type type: Optional[TaskAssignmentTypeField], optional
                :param message: A message that will is included with the task
        assignment. This is visible to the assigned user in the web and mobile
        UI., defaults to None
                :type message: Optional[str], optional
                :param completed_at: The date at which this task assignment was
        completed. This will be `null` if the task is not completed yet., defaults to None
                :type completed_at: Optional[DateTime], optional
                :param assigned_at: The date at which this task was assigned to the user., defaults to None
                :type assigned_at: Optional[DateTime], optional
                :param reminded_at: The date at which the assigned user was reminded of this task
        assignment., defaults to None
                :type reminded_at: Optional[DateTime], optional
                :param resolution_state: The current state of the assignment. The available states depend on
        the `action` value of the task object., defaults to None
                :type resolution_state: Optional[TaskAssignmentResolutionStateField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.item = item
        self.assigned_to = assigned_to
        self.message = message
        self.completed_at = completed_at
        self.assigned_at = assigned_at
        self.reminded_at = reminded_at
        self.resolution_state = resolution_state
        self.assigned_by = assigned_by



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class CollaborationAllowlistEntryTypeField(str, Enum):
    COLLABORATION_WHITELIST_ENTRY = 'collaboration_whitelist_entry'


class CollaborationAllowlistEntryDirectionField(str, Enum):
    INBOUND = 'inbound'
    OUTBOUND = 'outbound'
    BOTH = 'both'


class CollaborationAllowlistEntryEnterpriseTypeField(str, Enum):
    ENTERPRISE = 'enterprise'


class CollaborationAllowlistEntryEnterpriseField(BaseObject):
    _discriminator = 'type', {'enterprise'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[CollaborationAllowlistEntryEnterpriseTypeField] = None,
        name: Optional[str] = None,
        **kwargs
    ):
        """
        :param id: The unique identifier for this enterprise., defaults to None
        :type id: Optional[str], optional
        :param type: The value will always be `enterprise`., defaults to None
        :type type: Optional[CollaborationAllowlistEntryEnterpriseTypeField], optional
        :param name: The name of the enterprise., defaults to None
        :type name: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.name = name


class CollaborationAllowlistEntry(BaseObject):
    _discriminator = 'type', {'collaboration_whitelist_entry'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[CollaborationAllowlistEntryTypeField] = None,
        domain: Optional[str] = None,
        direction: Optional[CollaborationAllowlistEntryDirectionField] = None,
        enterprise: Optional[CollaborationAllowlistEntryEnterpriseField] = None,
        created_at: Optional[DateTime] = None,
        **kwargs
    ):
        """
        :param id: The unique identifier for this entry., defaults to None
        :type id: Optional[str], optional
        :param type: The value will always be `collaboration_whitelist_entry`., defaults to None
        :type type: Optional[CollaborationAllowlistEntryTypeField], optional
        :param domain: The whitelisted domain., defaults to None
        :type domain: Optional[str], optional
        :param direction: The direction of the collaborations to allow., defaults to None
        :type direction: Optional[CollaborationAllowlistEntryDirectionField], optional
        :param created_at: The time the entry was created at., defaults to None
        :type created_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.domain = domain
        self.direction = direction
        self.enterprise = enterprise
        self.created_at = created_at



from typing import Optional

from typing import Dict

from box_sdk_gen.schemas.metadata_base import MetadataBase

from box_sdk_gen.schemas.metadata import Metadata

from box_sdk_gen.box.errors import BoxSDKError


class MetadataFull(Metadata):
    _fields_to_json_mapping: Dict[str, str] = {
        'can_edit': '$canEdit',
        'id': '$id',
        'type': '$type',
        'type_version': '$typeVersion',
        **Metadata._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        '$canEdit': 'can_edit',
        '$id': 'id',
        '$type': 'type',
        '$typeVersion': 'type_version',
        **Metadata._json_to_fields_mapping,
    }

    def __init__(
        self,
        *,
        can_edit: Optional[bool] = None,
        id: Optional[str] = None,
        type: Optional[str] = None,
        type_version: Optional[int] = None,
        parent: Optional[str] = None,
        template: Optional[str] = None,
        scope: Optional[str] = None,
        version: Optional[int] = None,
        **kwargs
    ):
        """
                :param can_edit: Whether the user can edit this metadata instance., defaults to None
                :type can_edit: Optional[bool], optional
                :param id: A UUID to identify the metadata instance., defaults to None
                :type id: Optional[str], optional
                :param type: A unique identifier for the "type" of this instance. This is an
        internal system property and should not be used by a client
        application., defaults to None
                :type type: Optional[str], optional
                :param type_version: The last-known version of the template of the object. This is an
        internal system property and should not be used by a client
        application., defaults to None
                :type type_version: Optional[int], optional
                :param parent: The identifier of the item that this metadata instance
        has been attached to. This combines the `type` and the `id`
        of the parent in the form `{type}_{id}`., defaults to None
                :type parent: Optional[str], optional
                :param template: The name of the template., defaults to None
                :type template: Optional[str], optional
                :param scope: An ID for the scope in which this template
        has been applied. This will be `enterprise_{enterprise_id}` for templates
        defined for use in this enterprise, and `global` for general templates
        that are available to all enterprises using Box., defaults to None
                :type scope: Optional[str], optional
                :param version: The version of the metadata instance. This version starts at 0 and
        increases every time a user-defined property is modified., defaults to None
                :type version: Optional[int], optional
        """
        super().__init__(
            parent=parent, template=template, scope=scope, version=version, **kwargs
        )
        self.can_edit = can_edit
        self.id = id
        self.type = type
        self.type_version = type_version
        self.extra_data = kwargs



from typing import Union

from box_sdk_gen.schemas.sign_request_signer_input_email_validation import (
    SignRequestSignerInputEmailValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_custom_validation import (
    SignRequestSignerInputCustomValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_zip_validation import (
    SignRequestSignerInputZipValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_zip_4_validation import (
    SignRequestSignerInputZip4Validation,
)

from box_sdk_gen.schemas.sign_request_signer_input_ssn_validation import (
    SignRequestSignerInputSsnValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_number_with_period_validation import (
    SignRequestSignerInputNumberWithPeriodValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_number_with_comma_validation import (
    SignRequestSignerInputNumberWithCommaValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_date_iso_validation import (
    SignRequestSignerInputDateIsoValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_date_us_validation import (
    SignRequestSignerInputDateUsValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_date_eu_validation import (
    SignRequestSignerInputDateEuValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_date_asia_validation import (
    SignRequestSignerInputDateAsiaValidation,
)

from box_sdk_gen.box.errors import BoxSDKError

SignRequestSignerInputValidation = Union[
    SignRequestSignerInputEmailValidation,
    SignRequestSignerInputCustomValidation,
    SignRequestSignerInputZipValidation,
    SignRequestSignerInputZip4Validation,
    SignRequestSignerInputSsnValidation,
    SignRequestSignerInputNumberWithPeriodValidation,
    SignRequestSignerInputNumberWithCommaValidation,
    SignRequestSignerInputDateIsoValidation,
    SignRequestSignerInputDateUsValidation,
    SignRequestSignerInputDateEuValidation,
    SignRequestSignerInputDateAsiaValidation,
]



from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.v2025_r0.file_reference_v2025_r0 import FileReferenceV2025R0

from box_sdk_gen.box.errors import BoxSDKError


class DocGenTemplateCreateRequestV2025R0(BaseObject):
    def __init__(self, file: FileReferenceV2025R0, **kwargs):
        super().__init__(**kwargs)
        self.file = file



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.terms_of_service_base import TermsOfServiceBaseTypeField

from box_sdk_gen.schemas.terms_of_service_base import TermsOfServiceBase

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class TermsOfServiceStatusField(str, Enum):
    ENABLED = 'enabled'
    DISABLED = 'disabled'


class TermsOfServiceEnterpriseTypeField(str, Enum):
    ENTERPRISE = 'enterprise'


class TermsOfServiceEnterpriseField(BaseObject):
    _discriminator = 'type', {'enterprise'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[TermsOfServiceEnterpriseTypeField] = None,
        name: Optional[str] = None,
        **kwargs
    ):
        """
        :param id: The unique identifier for this enterprise., defaults to None
        :type id: Optional[str], optional
        :param type: The value will always be `enterprise`., defaults to None
        :type type: Optional[TermsOfServiceEnterpriseTypeField], optional
        :param name: The name of the enterprise., defaults to None
        :type name: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.name = name


class TermsOfServiceTosTypeField(str, Enum):
    MANAGED = 'managed'
    EXTERNAL = 'external'


class TermsOfService(TermsOfServiceBase):
    def __init__(
        self,
        id: str,
        *,
        status: Optional[TermsOfServiceStatusField] = None,
        enterprise: Optional[TermsOfServiceEnterpriseField] = None,
        tos_type: Optional[TermsOfServiceTosTypeField] = None,
        text: Optional[str] = None,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        type: TermsOfServiceBaseTypeField = TermsOfServiceBaseTypeField.TERMS_OF_SERVICE,
        **kwargs
    ):
        """
                :param id: The unique identifier for this terms of service.
                :type id: str
                :param status: Whether these terms are enabled or not., defaults to None
                :type status: Optional[TermsOfServiceStatusField], optional
                :param tos_type: Whether to apply these terms to managed users or external users., defaults to None
                :type tos_type: Optional[TermsOfServiceTosTypeField], optional
                :param text: The text for your terms and conditions. This text could be
        empty if the `status` is set to `disabled`., defaults to None
                :type text: Optional[str], optional
                :param created_at: When the legal item was created., defaults to None
                :type created_at: Optional[DateTime], optional
                :param modified_at: When the legal item was modified., defaults to None
                :type modified_at: Optional[DateTime], optional
                :param type: The value will always be `terms_of_service`., defaults to TermsOfServiceBaseTypeField.TERMS_OF_SERVICE
                :type type: TermsOfServiceBaseTypeField, optional
        """
        super().__init__(id=id, type=type, **kwargs)
        self.status = status
        self.enterprise = enterprise
        self.tos_type = tos_type
        self.text = text
        self.created_at = created_at
        self.modified_at = modified_at



from typing import Optional

from typing import Dict

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class MetadataBase(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'parent': '$parent',
        'template': '$template',
        'scope': '$scope',
        'version': '$version',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        '$parent': 'parent',
        '$template': 'template',
        '$scope': 'scope',
        '$version': 'version',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        *,
        parent: Optional[str] = None,
        template: Optional[str] = None,
        scope: Optional[str] = None,
        version: Optional[int] = None,
        **kwargs
    ):
        """
                :param parent: The identifier of the item that this metadata instance
        has been attached to. This combines the `type` and the `id`
        of the parent in the form `{type}_{id}`., defaults to None
                :type parent: Optional[str], optional
                :param template: The name of the template., defaults to None
                :type template: Optional[str], optional
                :param scope: An ID for the scope in which this template
        has been applied. This will be `enterprise_{enterprise_id}` for templates
        defined for use in this enterprise, and `global` for general templates
        that are available to all enterprises using Box., defaults to None
                :type scope: Optional[str], optional
                :param version: The version of the metadata instance. This version starts at 0 and
        increases every time a user-defined property is modified., defaults to None
                :type version: Optional[int], optional
        """
        super().__init__(**kwargs)
        self.parent = parent
        self.template = template
        self.scope = scope
        self.version = version



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class KeysafeSettingsV2025R0(BaseObject):
    def __init__(
        self,
        *,
        keysafe_enabled: Optional[bool] = None,
        cloud_provider: Optional[str] = None,
        key_id: Optional[str] = None,
        account_id: Optional[str] = None,
        location_id: Optional[str] = None,
        project_id: Optional[str] = None,
        keyring_id: Optional[str] = None,
        **kwargs
    ):
        """
        :param keysafe_enabled: Whether KeySafe addon is enabled for the enterprise., defaults to None
        :type keysafe_enabled: Optional[bool], optional
        :param cloud_provider: The cloud provider., defaults to None
        :type cloud_provider: Optional[str], optional
        :param key_id: The key ID., defaults to None
        :type key_id: Optional[str], optional
        :param account_id: The account ID., defaults to None
        :type account_id: Optional[str], optional
        :param location_id: The location ID., defaults to None
        :type location_id: Optional[str], optional
        :param project_id: The project ID., defaults to None
        :type project_id: Optional[str], optional
        :param keyring_id: The key ring ID., defaults to None
        :type keyring_id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.keysafe_enabled = keysafe_enabled
        self.cloud_provider = cloud_provider
        self.key_id = key_id
        self.account_id = account_id
        self.location_id = location_id
        self.project_id = project_id
        self.keyring_id = keyring_id



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class ListUserV2025R0(BaseObject):
    def __init__(
        self,
        *,
        id: Optional[int] = None,
        name: Optional[str] = None,
        email: Optional[str] = None,
        **kwargs
    ):
        """
        :param id: The ID of the user., defaults to None
        :type id: Optional[int], optional
        :param name: The name of the user., defaults to None
        :type name: Optional[str], optional
        :param email: The email of the user., defaults to None
        :type email: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.name = name
        self.email = email



from enum import Enum

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.terms_of_services import TermsOfServices

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.terms_of_service import TermsOfService

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class GetTermsOfServiceTosType(str, Enum):
    EXTERNAL = 'external'
    MANAGED = 'managed'


class CreateTermsOfServiceStatus(str, Enum):
    ENABLED = 'enabled'
    DISABLED = 'disabled'


class CreateTermsOfServiceTosType(str, Enum):
    EXTERNAL = 'external'
    MANAGED = 'managed'


class UpdateTermsOfServiceByIdStatus(str, Enum):
    ENABLED = 'enabled'
    DISABLED = 'disabled'


class TermsOfServicesManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_terms_of_service(
        self,
        *,
        tos_type: Optional[GetTermsOfServiceTosType] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> TermsOfServices:
        """
        Returns the current terms of service text and settings

        for the enterprise.

        :param tos_type: Limits the results to the terms of service of the given type., defaults to None
        :type tos_type: Optional[GetTermsOfServiceTosType], optional
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'tos_type': to_string(tos_type)}
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/terms_of_services']
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, TermsOfServices)

    def create_terms_of_service(
        self,
        status: CreateTermsOfServiceStatus,
        text: str,
        *,
        tos_type: Optional[CreateTermsOfServiceTosType] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> TermsOfService:
        """
                Creates a terms of service for a given enterprise

                and type of user.

                :param status: Whether this terms of service is active.
                :type status: CreateTermsOfServiceStatus
                :param text: The terms of service text to display to users.

        The text can be set to empty if the `status` is set to `disabled`.
                :type text: str
                :param tos_type: The type of user to set the terms of
        service for., defaults to None
                :type tos_type: Optional[CreateTermsOfServiceTosType], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'status': status, 'tos_type': tos_type, 'text': text}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/terms_of_services']
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, TermsOfService)

    def get_terms_of_service_by_id(
        self,
        terms_of_service_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> TermsOfService:
        """
                Fetches a specific terms of service.
                :param terms_of_service_id: The ID of the terms of service.
        Example: "324234"
                :type terms_of_service_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/terms_of_services/',
                        to_string(terms_of_service_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, TermsOfService)

    def update_terms_of_service_by_id(
        self,
        terms_of_service_id: str,
        status: UpdateTermsOfServiceByIdStatus,
        text: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> TermsOfService:
        """
                Updates a specific terms of service.
                :param terms_of_service_id: The ID of the terms of service.
        Example: "324234"
                :type terms_of_service_id: str
                :param status: Whether this terms of service is active.
                :type status: UpdateTermsOfServiceByIdStatus
                :param text: The terms of service text to display to users.

        The text can be set to empty if the `status` is set to `disabled`.
                :type text: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'status': status, 'text': text}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/terms_of_services/',
                        to_string(terms_of_service_id),
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, TermsOfService)



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from typing import Optional

from box_sdk_gen.box.errors import BoxSDKError


class HubCollaborationCreateRequestV2025R0HubTypeField(str, Enum):
    HUBS = 'hubs'


class HubCollaborationCreateRequestV2025R0HubField(BaseObject):
    _discriminator = 'type', {'hubs'}

    def __init__(
        self,
        id: str,
        *,
        type: HubCollaborationCreateRequestV2025R0HubTypeField = HubCollaborationCreateRequestV2025R0HubTypeField.HUBS,
        **kwargs
    ):
        """
        :param id: ID of the object.
        :type id: str
        :param type: The value will always be `hubs`., defaults to HubCollaborationCreateRequestV2025R0HubTypeField.HUBS
        :type type: HubCollaborationCreateRequestV2025R0HubTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class HubCollaborationCreateRequestV2025R0AccessibleByField(BaseObject):
    def __init__(
        self,
        type: str,
        *,
        id: Optional[str] = None,
        login: Optional[str] = None,
        **kwargs
    ):
        """
                :param type: The type of collaborator to invite.
        Possible values are `user` or `group`.
                :type type: str
                :param id: The ID of the user or group.

        Alternatively, use `login` to specify a user by email
        address., defaults to None
                :type id: Optional[str], optional
                :param login: The email address of the user who gets access to the item.

        Alternatively, use `id` to specify a user by user ID., defaults to None
                :type login: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id
        self.login = login


class HubCollaborationCreateRequestV2025R0(BaseObject):
    def __init__(
        self,
        hub: HubCollaborationCreateRequestV2025R0HubField,
        accessible_by: HubCollaborationCreateRequestV2025R0AccessibleByField,
        role: str,
        **kwargs
    ):
        """
                :param hub: Box Hubs reference.
                :type hub: HubCollaborationCreateRequestV2025R0HubField
                :param accessible_by: The user or group who gets access to the item.
                :type accessible_by: HubCollaborationCreateRequestV2025R0AccessibleByField
                :param role: The level of access granted to a Box Hub.
        Possible values are `editor`, `viewer`, and `co-owner`.
                :type role: str
        """
        super().__init__(**kwargs)
        self.hub = hub
        self.accessible_by = accessible_by
        self.role = role



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.schemas.group_full import GroupFull

from box_sdk_gen.box.errors import BoxSDKError


class GroupsOrderDirectionField(str, Enum):
    ASC = 'ASC'
    DESC = 'DESC'


class GroupsOrderField(BaseObject):
    def __init__(
        self,
        *,
        by: Optional[str] = None,
        direction: Optional[GroupsOrderDirectionField] = None,
        **kwargs
    ):
        """
        :param by: The field to order by., defaults to None
        :type by: Optional[str], optional
        :param direction: The direction to order by, either ascending or descending., defaults to None
        :type direction: Optional[GroupsOrderDirectionField], optional
        """
        super().__init__(**kwargs)
        self.by = by
        self.direction = direction


class Groups(BaseObject):
    def __init__(
        self,
        *,
        total_count: Optional[int] = None,
        limit: Optional[int] = None,
        offset: Optional[int] = None,
        order: Optional[List[GroupsOrderField]] = None,
        entries: Optional[List[GroupFull]] = None,
        **kwargs
    ):
        """
                :param total_count: One greater than the offset of the last entry in the entire collection.
        The total number of entries in the collection may be less than
        `total_count`.

        This field is only returned for calls that use offset-based pagination.
        For marker-based paginated APIs, this field will be omitted., defaults to None
                :type total_count: Optional[int], optional
                :param limit: The limit that was used for these entries. This will be the same as the
        `limit` query parameter unless that value exceeded the maximum value
        allowed. The maximum value varies by API., defaults to None
                :type limit: Optional[int], optional
                :param offset: The 0-based offset of the first entry in this set. This will be the same
        as the `offset` query parameter.

        This field is only returned for calls that use offset-based pagination.
        For marker-based paginated APIs, this field will be omitted., defaults to None
                :type offset: Optional[int], optional
                :param order: The order by which items are returned.

        This field is only returned for calls that use offset-based pagination.
        For marker-based paginated APIs, this field will be omitted., defaults to None
                :type order: Optional[List[GroupsOrderField]], optional
                :param entries: A list of groups., defaults to None
                :type entries: Optional[List[GroupFull]], optional
        """
        super().__init__(**kwargs)
        self.total_count = total_count
        self.limit = limit
        self.offset = offset
        self.order = order
        self.entries = entries



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class AiDialogueHistory(BaseObject):
    def __init__(
        self,
        *,
        prompt: Optional[str] = None,
        answer: Optional[str] = None,
        created_at: Optional[DateTime] = None,
        **kwargs
    ):
        """
        :param prompt: The prompt previously provided by the client and answered by the LLM., defaults to None
        :type prompt: Optional[str], optional
        :param answer: The answer previously provided by the LLM., defaults to None
        :type answer: Optional[str], optional
        :param created_at: The ISO date formatted timestamp of when the previous answer to the prompt was created., defaults to None
        :type created_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.prompt = prompt
        self.answer = answer
        self.created_at = created_at



from typing import List

from typing import Optional

from typing import Dict

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.internal.utils import Buffer

from box_sdk_gen.internal.utils import HashName

from box_sdk_gen.internal.utils import Iterator

from box_sdk_gen.schemas.upload_session import UploadSession

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.uploaded_part import UploadedPart

from box_sdk_gen.schemas.upload_parts import UploadParts

from box_sdk_gen.schemas.files import Files

from box_sdk_gen.schemas.upload_part import UploadPart

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import SerializedData

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.internal.utils import generate_byte_stream_from_buffer

from box_sdk_gen.internal.utils import hex_to_base_64

from box_sdk_gen.internal.utils import iterate_chunks

from box_sdk_gen.internal.utils import read_byte_stream

from box_sdk_gen.internal.utils import reduce_iterator

from box_sdk_gen.internal.utils import Hash

from box_sdk_gen.internal.utils import buffer_length

from box_sdk_gen.schemas.file_full import FileFull


class _PartAccumulator:
    def __init__(
        self,
        last_index: int,
        parts: List[UploadPart],
        file_size: int,
        upload_part_url: str,
        file_hash: Hash,
    ):
        self.last_index = last_index
        self.parts = parts
        self.file_size = file_size
        self.upload_part_url = upload_part_url
        self.file_hash = file_hash


class ChunkedUploadsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def create_file_upload_session(
        self,
        folder_id: str,
        file_size: int,
        file_name: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> UploadSession:
        """
        Creates an upload session for a new file.
        :param folder_id: The ID of the folder to upload the new file to.
        :type folder_id: str
        :param file_size: The total number of bytes of the file to be uploaded.
        :type file_size: int
        :param file_name: The name of new file.
        :type file_name: str
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'folder_id': folder_id,
            'file_size': file_size,
            'file_name': file_name,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.upload_url,
                        '/2.0/files/upload_sessions',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, UploadSession)

    def create_file_upload_session_for_existing_file(
        self,
        file_id: str,
        file_size: int,
        *,
        file_name: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> UploadSession:
        """
                Creates an upload session for an existing file.
                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param file_size: The total number of bytes of the file to be uploaded.
                :type file_size: int
                :param file_name: The optional new name of new file., defaults to None
                :type file_name: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'file_size': file_size, 'file_name': file_name}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.upload_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/upload_sessions',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, UploadSession)

    def get_file_upload_session_by_url(
        self, url: str, *, extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> UploadSession:
        """
        Using this method with urls provided in response when creating a new upload session is preferred to use over GetFileUploadSessionById method.

        This allows to always upload your content to the closest Box data center and can significantly improve upload speed.


         Return information about an upload session.


        The actual endpoint URL is returned by the [`Create upload session`](https://developer.box.com/reference/post-files-upload-sessions) endpoint.

        :param url: URL of getFileUploadSessionById method
        :type url: str
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=url,
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, UploadSession)

    def get_file_upload_session_by_id(
        self,
        upload_session_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> UploadSession:
        """
                Return information about an upload session.

                The actual endpoint URL is returned by the [`Create upload session`](https://developer.box.com/reference/post-files-upload-sessions) endpoint.

                :param upload_session_id: The ID of the upload session.
        Example: "D5E3F7A"
                :type upload_session_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.upload_url,
                        '/2.0/files/upload_sessions/',
                        to_string(upload_session_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, UploadSession)

    def upload_file_part_by_url(
        self,
        url: str,
        request_body: ByteStream,
        digest: str,
        content_range: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> UploadedPart:
        """
                Using this method with urls provided in response when creating a new upload session is preferred to use over UploadFilePart method.

                This allows to always upload your content to the closest Box data center and can significantly improve upload speed.


                 Uploads a chunk of a file for an upload session.


                The actual endpoint URL is returned by the [`Create upload session`](https://developer.box.com/reference/post-files-upload-sessions)


                and [`Get upload session`](https://developer.box.com/reference/get-files-upload-sessions-id) endpoints.

                :param url: URL of uploadFilePart method
                :type url: str
                :param request_body: Request body of uploadFilePart method
                :type request_body: ByteStream
                :param digest: The [RFC3230][1] message digest of the chunk uploaded.

        Only SHA1 is supported. The SHA1 digest must be base64
        encoded. The format of this header is as
        `sha=BASE64_ENCODED_DIGEST`.

        To get the value for the `SHA` digest, use the
        openSSL command to encode the file part:
        `openssl sha1 -binary <FILE_PART_NAME> | base64`.

        [1]: https://tools.ietf.org/html/rfc3230
                :type digest: str
                :param content_range: The byte range of the chunk.

        Must not overlap with the range of a part already
        uploaded this session. Each part’s size must be
        exactly equal in size to the part size specified
        in the upload session that you created.
        One exception is the last part of the file, as this can be smaller.

        When providing the value for `content-range`, remember that:

        * The lower bound of each part's byte range
          must be a multiple of the part size.
        * The higher bound must be a multiple of the part size - 1.
                :type content_range: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params(
            {
                'digest': to_string(digest),
                'content-range': to_string(content_range),
                **extra_headers,
            }
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=url,
                method='PUT',
                headers=headers_map,
                file_stream=request_body,
                content_type='application/octet-stream',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, UploadedPart)

    def upload_file_part(
        self,
        upload_session_id: str,
        request_body: ByteStream,
        digest: str,
        content_range: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> UploadedPart:
        """
                Uploads a chunk of a file for an upload session.

                The actual endpoint URL is returned by the [`Create upload session`](https://developer.box.com/reference/post-files-upload-sessions)


                and [`Get upload session`](https://developer.box.com/reference/get-files-upload-sessions-id) endpoints.

                :param upload_session_id: The ID of the upload session.
        Example: "D5E3F7A"
                :type upload_session_id: str
                :param request_body: Request body of uploadFilePart method
                :type request_body: ByteStream
                :param digest: The [RFC3230][1] message digest of the chunk uploaded.

        Only SHA1 is supported. The SHA1 digest must be base64
        encoded. The format of this header is as
        `sha=BASE64_ENCODED_DIGEST`.

        To get the value for the `SHA` digest, use the
        openSSL command to encode the file part:
        `openssl sha1 -binary <FILE_PART_NAME> | base64`.

        [1]: https://tools.ietf.org/html/rfc3230
                :type digest: str
                :param content_range: The byte range of the chunk.

        Must not overlap with the range of a part already
        uploaded this session. Each part’s size must be
        exactly equal in size to the part size specified
        in the upload session that you created.
        One exception is the last part of the file, as this can be smaller.

        When providing the value for `content-range`, remember that:

        * The lower bound of each part's byte range
          must be a multiple of the part size.
        * The higher bound must be a multiple of the part size - 1.
                :type content_range: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params(
            {
                'digest': to_string(digest),
                'content-range': to_string(content_range),
                **extra_headers,
            }
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.upload_url,
                        '/2.0/files/upload_sessions/',
                        to_string(upload_session_id),
                    ]
                ),
                method='PUT',
                headers=headers_map,
                file_stream=request_body,
                content_type='application/octet-stream',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, UploadedPart)

    def delete_file_upload_session_by_url(
        self, url: str, *, extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
        Using this method with urls provided in response when creating a new upload session is preferred to use over DeleteFileUploadSessionById method.

        This allows to always upload your content to the closest Box data center and can significantly improve upload speed.


         Abort an upload session and discard all data uploaded.


        This cannot be reversed.


        The actual endpoint URL is returned by the [`Create upload session`](https://developer.box.com/reference/post-files-upload-sessions)


        and [`Get upload session`](https://developer.box.com/reference/get-files-upload-sessions-id) endpoints.

        :param url: URL of deleteFileUploadSessionById method
        :type url: str
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=url,
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def delete_file_upload_session_by_id(
        self,
        upload_session_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Abort an upload session and discard all data uploaded.

                This cannot be reversed.


                The actual endpoint URL is returned by the [`Create upload session`](https://developer.box.com/reference/post-files-upload-sessions)


                and [`Get upload session`](https://developer.box.com/reference/get-files-upload-sessions-id) endpoints.

                :param upload_session_id: The ID of the upload session.
        Example: "D5E3F7A"
                :type upload_session_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.upload_url,
                        '/2.0/files/upload_sessions/',
                        to_string(upload_session_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def get_file_upload_session_parts_by_url(
        self,
        url: str,
        *,
        offset: Optional[int] = None,
        limit: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> UploadParts:
        """
                Using this method with urls provided in response when creating a new upload session is preferred to use over GetFileUploadSessionParts method.

                This allows to always upload your content to the closest Box data center and can significantly improve upload speed.


                 Return a list of the chunks uploaded to the upload session so far.


                The actual endpoint URL is returned by the [`Create upload session`](https://developer.box.com/reference/post-files-upload-sessions)


                and [`Get upload session`](https://developer.box.com/reference/get-files-upload-sessions-id) endpoints.

                :param url: URL of getFileUploadSessionParts method
                :type url: str
                :param offset: The offset of the item at which to begin the response.

        Queries with offset parameter value
        exceeding 10000 will be rejected
        with a 400 response., defaults to None
                :type offset: Optional[int], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'offset': to_string(offset), 'limit': to_string(limit)}
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=url,
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, UploadParts)

    def get_file_upload_session_parts(
        self,
        upload_session_id: str,
        *,
        offset: Optional[int] = None,
        limit: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> UploadParts:
        """
                Return a list of the chunks uploaded to the upload session so far.

                The actual endpoint URL is returned by the [`Create upload session`](https://developer.box.com/reference/post-files-upload-sessions)


                and [`Get upload session`](https://developer.box.com/reference/get-files-upload-sessions-id) endpoints.

                :param upload_session_id: The ID of the upload session.
        Example: "D5E3F7A"
                :type upload_session_id: str
                :param offset: The offset of the item at which to begin the response.

        Queries with offset parameter value
        exceeding 10000 will be rejected
        with a 400 response., defaults to None
                :type offset: Optional[int], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'offset': to_string(offset), 'limit': to_string(limit)}
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.upload_url,
                        '/2.0/files/upload_sessions/',
                        to_string(upload_session_id),
                        '/parts',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, UploadParts)

    def create_file_upload_session_commit_by_url(
        self,
        url: str,
        parts: List[UploadPart],
        digest: str,
        *,
        if_match: Optional[str] = None,
        if_none_match: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Optional[Files]:
        """
                Using this method with urls provided in response when creating a new upload session is preferred to use over CreateFileUploadSessionCommit method.

                This allows to always upload your content to the closest Box data center and can significantly improve upload speed.


                 Close an upload session and create a file from the uploaded chunks.


                The actual endpoint URL is returned by the [`Create upload session`](https://developer.box.com/reference/post-files-upload-sessions)


                and [`Get upload session`](https://developer.box.com/reference/get-files-upload-sessions-id) endpoints.

                :param url: URL of createFileUploadSessionCommit method
                :type url: str
                :param parts: The list details for the uploaded parts.
                :type parts: List[UploadPart]
                :param digest: The [RFC3230][1] message digest of the whole file.

        Only SHA1 is supported. The SHA1 digest must be Base64
        encoded. The format of this header is as
        `sha=BASE64_ENCODED_DIGEST`.

        [1]: https://tools.ietf.org/html/rfc3230
                :type digest: str
                :param if_match: Ensures this item hasn't recently changed before
        making changes.

        Pass in the item's last observed `etag` value
        into this header and the endpoint will fail
        with a `412 Precondition Failed` if it
        has changed since., defaults to None
                :type if_match: Optional[str], optional
                :param if_none_match: Ensures an item is only returned if it has changed.

        Pass in the item's last observed `etag` value
        into this header and the endpoint will fail
        with a `304 Not Modified` if the item has not
        changed since., defaults to None
                :type if_none_match: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'parts': parts}
        headers_map: Dict[str, str] = prepare_params(
            {
                'digest': to_string(digest),
                'if-match': to_string(if_match),
                'if-none-match': to_string(if_none_match),
                **extra_headers,
            }
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=url,
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        if to_string(response.status) == '202':
            return None
        return deserialize(response.data, Files)

    def create_file_upload_session_commit(
        self,
        upload_session_id: str,
        parts: List[UploadPart],
        digest: str,
        *,
        if_match: Optional[str] = None,
        if_none_match: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Optional[Files]:
        """
                Close an upload session and create a file from the uploaded chunks.

                The actual endpoint URL is returned by the [`Create upload session`](https://developer.box.com/reference/post-files-upload-sessions)


                and [`Get upload session`](https://developer.box.com/reference/get-files-upload-sessions-id) endpoints.

                :param upload_session_id: The ID of the upload session.
        Example: "D5E3F7A"
                :type upload_session_id: str
                :param parts: The list details for the uploaded parts.
                :type parts: List[UploadPart]
                :param digest: The [RFC3230][1] message digest of the whole file.

        Only SHA1 is supported. The SHA1 digest must be Base64
        encoded. The format of this header is as
        `sha=BASE64_ENCODED_DIGEST`.

        [1]: https://tools.ietf.org/html/rfc3230
                :type digest: str
                :param if_match: Ensures this item hasn't recently changed before
        making changes.

        Pass in the item's last observed `etag` value
        into this header and the endpoint will fail
        with a `412 Precondition Failed` if it
        has changed since., defaults to None
                :type if_match: Optional[str], optional
                :param if_none_match: Ensures an item is only returned if it has changed.

        Pass in the item's last observed `etag` value
        into this header and the endpoint will fail
        with a `304 Not Modified` if the item has not
        changed since., defaults to None
                :type if_none_match: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'parts': parts}
        headers_map: Dict[str, str] = prepare_params(
            {
                'digest': to_string(digest),
                'if-match': to_string(if_match),
                'if-none-match': to_string(if_none_match),
                **extra_headers,
            }
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.upload_url,
                        '/2.0/files/upload_sessions/',
                        to_string(upload_session_id),
                        '/commit',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        if to_string(response.status) == '202':
            return None
        return deserialize(response.data, Files)

    def _reducer(self, acc: _PartAccumulator, chunk: ByteStream) -> _PartAccumulator:
        last_index: int = acc.last_index
        parts: List[UploadPart] = acc.parts
        chunk_buffer: Buffer = read_byte_stream(chunk)
        hash: Hash = Hash(algorithm=HashName.SHA1)
        hash.update_hash(chunk_buffer)
        sha_1: str = hash.digest_hash('base64')
        digest: str = ''.join(['sha=', sha_1])
        chunk_size: int = buffer_length(chunk_buffer)
        bytes_start: int = last_index + 1
        bytes_end: int = last_index + chunk_size
        content_range: str = ''.join(
            [
                'bytes ',
                to_string(bytes_start),
                '-',
                to_string(bytes_end),
                '/',
                to_string(acc.file_size),
            ]
        )
        uploaded_part: UploadedPart = self.upload_file_part_by_url(
            acc.upload_part_url,
            generate_byte_stream_from_buffer(chunk_buffer),
            digest,
            content_range,
        )
        part: UploadPart = uploaded_part.part
        part_sha_1: str = hex_to_base_64(part.sha_1)
        assert part_sha_1 == sha_1
        assert part.size == chunk_size
        assert part.offset == bytes_start
        acc.file_hash.update_hash(chunk_buffer)
        return _PartAccumulator(
            last_index=bytes_end,
            parts=parts + [part],
            file_size=acc.file_size,
            upload_part_url=acc.upload_part_url,
            file_hash=acc.file_hash,
        )

    def upload_big_file(
        self, file: ByteStream, file_name: str, file_size: int, parent_folder_id: str
    ) -> FileFull:
        """
        Starts the process of chunk uploading a big file. Should return a File object representing uploaded file.
        :param file: The stream of the file to upload.
        :type file: ByteStream
        :param file_name: The name of the file, which will be used for storage in Box.
        :type file_name: str
        :param file_size: The total size of the file for the chunked upload in bytes.
        :type file_size: int
        :param parent_folder_id: The ID of the folder where the file should be uploaded.
        :type parent_folder_id: str
        """
        upload_session: UploadSession = self.create_file_upload_session(
            parent_folder_id, file_size, file_name
        )
        upload_part_url: str = upload_session.session_endpoints.upload_part
        commit_url: str = upload_session.session_endpoints.commit
        list_parts_url: str = upload_session.session_endpoints.list_parts
        part_size: int = upload_session.part_size
        total_parts: int = upload_session.total_parts
        assert part_size * total_parts >= file_size
        assert upload_session.num_parts_processed == 0
        file_hash: Hash = Hash(algorithm=HashName.SHA1)
        chunks_iterator: Iterator = iterate_chunks(file, part_size, file_size)
        results: _PartAccumulator = reduce_iterator(
            chunks_iterator,
            self._reducer,
            _PartAccumulator(
                last_index=-1,
                parts=[],
                file_size=file_size,
                upload_part_url=upload_part_url,
                file_hash=file_hash,
            ),
        )
        parts: List[UploadPart] = results.parts
        processed_session_parts: UploadParts = (
            self.get_file_upload_session_parts_by_url(list_parts_url)
        )
        assert processed_session_parts.total_count == total_parts
        sha_1: str = file_hash.digest_hash('base64')
        digest: str = ''.join(['sha=', sha_1])
        committed_session: Optional[Files] = (
            self.create_file_upload_session_commit_by_url(commit_url, parts, digest)
        )
        return committed_session.entries[0]



from enum import Enum

from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.search_result_with_shared_link import (
    SearchResultWithSharedLink,
)

from box_sdk_gen.box.errors import BoxSDKError


class SearchResultsWithSharedLinksTypeField(str, Enum):
    SEARCH_RESULTS_WITH_SHARED_LINKS = 'search_results_with_shared_links'


class SearchResultsWithSharedLinks(BaseObject):
    _discriminator = 'type', {'search_results_with_shared_links'}

    def __init__(
        self,
        *,
        total_count: Optional[int] = None,
        limit: Optional[int] = None,
        offset: Optional[int] = None,
        type: SearchResultsWithSharedLinksTypeField = SearchResultsWithSharedLinksTypeField.SEARCH_RESULTS_WITH_SHARED_LINKS,
        entries: Optional[List[SearchResultWithSharedLink]] = None,
        **kwargs
    ):
        """
                :param total_count: One greater than the offset of the last entry in the search results.
        The total number of entries in the collection may be less than
        `total_count`., defaults to None
                :type total_count: Optional[int], optional
                :param limit: The limit that was used for this search. This will be the same as the
        `limit` query parameter unless that value exceeded the maximum value
        allowed., defaults to None
                :type limit: Optional[int], optional
                :param offset: The 0-based offset of the first entry in this set. This will be the same
        as the `offset` query parameter used., defaults to None
                :type offset: Optional[int], optional
                :param type: Specifies the response as search result items with shared links., defaults to SearchResultsWithSharedLinksTypeField.SEARCH_RESULTS_WITH_SHARED_LINKS
                :type type: SearchResultsWithSharedLinksTypeField, optional
                :param entries: The search results for the query provided, including the
        additional information about any shared links through
        which the item has been shared with the user., defaults to None
                :type entries: Optional[List[SearchResultWithSharedLink]], optional
        """
        super().__init__(**kwargs)
        self.total_count = total_count
        self.limit = limit
        self.offset = offset
        self.type = type
        self.entries = entries



from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.file_version_legal_hold import FileVersionLegalHold

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.file_version_legal_holds import FileVersionLegalHolds

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class FileVersionLegalHoldsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_file_version_legal_hold_by_id(
        self,
        file_version_legal_hold_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> FileVersionLegalHold:
        """
                Retrieves information about the legal hold policies

                assigned to a file version.

                :param file_version_legal_hold_id: The ID of the file version legal hold.
        Example: "2348213"
                :type file_version_legal_hold_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/file_version_legal_holds/',
                        to_string(file_version_legal_hold_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, FileVersionLegalHold)

    def get_file_version_legal_holds(
        self,
        policy_id: str,
        *,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> FileVersionLegalHolds:
        """
                Get a list of file versions on legal hold for a legal hold

                assignment.


                Due to ongoing re-architecture efforts this API might not return all file


                versions for this policy ID.


                Instead, this API will only return file versions held in the legacy


                architecture. Two new endpoints will available to request any file versions


                held in the new architecture.


                For file versions held in the new architecture, the `GET


                /legal_hold_policy_assignments/:id/file_versions_on_hold` API can be used to


                return all past file versions available for this policy assignment, and the


                `GET /legal_hold_policy_assignments/:id/files_on_hold` API can be used to


                return any current (latest) versions of a file under legal hold.


                The `GET /legal_hold_policy_assignments?policy_id={id}` API can be used to


                find a list of policy assignments for a given policy ID.


                Once the re-architecture is completed this API will be deprecated.

                :param policy_id: The ID of the legal hold policy to get the file version legal
        holds for.
                :type policy_id: str
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'policy_id': to_string(policy_id),
                'marker': to_string(marker),
                'limit': to_string(limit),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/file_version_legal_holds',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, FileVersionLegalHolds)



from enum import Enum

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class ShieldListContentDomainV2025R0TypeField(str, Enum):
    DOMAIN = 'domain'


class ShieldListContentDomainV2025R0(BaseObject):
    _discriminator = 'type', {'domain'}

    def __init__(
        self,
        domains: List[str],
        *,
        type: ShieldListContentDomainV2025R0TypeField = ShieldListContentDomainV2025R0TypeField.DOMAIN,
        **kwargs
    ):
        """
        :param domains: List of domain.
        :type domains: List[str]
        :param type: The type of content in the shield list., defaults to ShieldListContentDomainV2025R0TypeField.DOMAIN
        :type type: ShieldListContentDomainV2025R0TypeField, optional
        """
        super().__init__(**kwargs)
        self.domains = domains
        self.type = type



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class PostOAuth2Revoke(BaseObject):
    def __init__(
        self,
        *,
        client_id: Optional[str] = None,
        client_secret: Optional[str] = None,
        token: Optional[str] = None,
        **kwargs
    ):
        """
                :param client_id: The Client ID of the application requesting to revoke the
        access token., defaults to None
                :type client_id: Optional[str], optional
                :param client_secret: The client secret of the application requesting to revoke
        an access token., defaults to None
                :type client_secret: Optional[str], optional
                :param token: The access token to revoke., defaults to None
                :type token: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.client_id = client_id
        self.client_secret = client_secret
        self.token = token



from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.file_full import FileFull

from box_sdk_gen.box.errors import BoxSDKError


class Files(BaseObject):
    def __init__(
        self,
        *,
        total_count: Optional[int] = None,
        entries: Optional[List[FileFull]] = None,
        **kwargs
    ):
        """
        :param total_count: The number of files., defaults to None
        :type total_count: Optional[int], optional
        :param entries: A list of files., defaults to None
        :type entries: Optional[List[FileFull]], optional
        """
        super().__init__(**kwargs)
        self.total_count = total_count
        self.entries = entries



from enum import Enum

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from typing import Optional

from box_sdk_gen.schemas.folder_mini import FolderMini

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class TrashWebLinkRestoredTypeField(str, Enum):
    WEB_LINK = 'web_link'


class TrashWebLinkRestoredPathCollectionField(BaseObject):
    def __init__(self, total_count: int, entries: List[FolderMini], **kwargs):
        """
        :param total_count: The number of folders in this list.
        :type total_count: int
        :param entries: The parent folders for this item.
        :type entries: List[FolderMini]
        """
        super().__init__(**kwargs)
        self.total_count = total_count
        self.entries = entries


class TrashWebLinkRestoredItemStatusField(str, Enum):
    ACTIVE = 'active'
    TRASHED = 'trashed'
    DELETED = 'deleted'


class TrashWebLinkRestored(BaseObject):
    _discriminator = 'type', {'web_link'}

    def __init__(
        self,
        sequence_id: str,
        path_collection: TrashWebLinkRestoredPathCollectionField,
        *,
        type: Optional[TrashWebLinkRestoredTypeField] = None,
        id: Optional[str] = None,
        etag: Optional[str] = None,
        name: Optional[str] = None,
        url: Optional[str] = None,
        parent: Optional[FolderMini] = None,
        description: Optional[str] = None,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        trashed_at: Optional[str] = None,
        purged_at: Optional[str] = None,
        created_by: Optional[UserMini] = None,
        modified_by: Optional[UserMini] = None,
        owned_by: Optional[UserMini] = None,
        shared_link: Optional[str] = None,
        item_status: Optional[TrashWebLinkRestoredItemStatusField] = None,
        **kwargs
    ):
        """
                :param type: The value will always be `web_link`., defaults to None
                :type type: Optional[TrashWebLinkRestoredTypeField], optional
                :param id: The unique identifier for this web link., defaults to None
                :type id: Optional[str], optional
                :param etag: The entity tag of this web link. Used with `If-Match`
        headers., defaults to None
                :type etag: Optional[str], optional
                :param name: The name of the web link., defaults to None
                :type name: Optional[str], optional
                :param url: The URL this web link points to., defaults to None
                :type url: Optional[str], optional
                :param description: The description accompanying the web link. This is
        visible within the Box web application., defaults to None
                :type description: Optional[str], optional
                :param created_at: When this file was created on Box’s servers., defaults to None
                :type created_at: Optional[DateTime], optional
                :param modified_at: When this file was last updated on the Box
        servers., defaults to None
                :type modified_at: Optional[DateTime], optional
                :param trashed_at: The time at which this bookmark was put in the
        trash - becomes `null` after restore., defaults to None
                :type trashed_at: Optional[str], optional
                :param purged_at: The time at which this bookmark will be permanently
        deleted - becomes `null` after restore., defaults to None
                :type purged_at: Optional[str], optional
                :param shared_link: The shared link for this bookmark. This will
        be `null` if a bookmark had been trashed, even though the original shared
        link does become active again., defaults to None
                :type shared_link: Optional[str], optional
                :param item_status: Whether this item is deleted or not. Values include `active`,
        `trashed` if the file has been moved to the trash, and `deleted` if
        the file has been permanently deleted., defaults to None
                :type item_status: Optional[TrashWebLinkRestoredItemStatusField], optional
        """
        super().__init__(**kwargs)
        self.sequence_id = sequence_id
        self.path_collection = path_collection
        self.type = type
        self.id = id
        self.etag = etag
        self.name = name
        self.url = url
        self.parent = parent
        self.description = description
        self.created_at = created_at
        self.modified_at = modified_at
        self.trashed_at = trashed_at
        self.purged_at = purged_at
        self.created_by = created_by
        self.modified_by = modified_by
        self.owned_by = owned_by
        self.shared_link = shared_link
        self.item_status = item_status



from enum import Enum

from typing import Optional

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.collaborations import Collaborations

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.collaborations_offset_paginated import (
    CollaborationsOffsetPaginated,
)

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class GetCollaborationsStatus(str, Enum):
    PENDING = 'pending'


class ListCollaborationsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_file_collaborations(
        self,
        file_id: str,
        *,
        fields: Optional[List[str]] = None,
        limit: Optional[int] = None,
        marker: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Collaborations:
        """
                Retrieves a list of pending and active collaborations for a

                file. This returns all the users that have access to the file


                or have been invited to the file.

                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'fields': to_string(fields),
                'limit': to_string(limit),
                'marker': to_string(marker),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/collaborations',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Collaborations)

    def get_folder_collaborations(
        self,
        folder_id: str,
        *,
        fields: Optional[List[str]] = None,
        limit: Optional[int] = None,
        marker: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Collaborations:
        """
                Retrieves a list of pending and active collaborations for a

                folder. This returns all the users that have access to the folder


                or have been invited to the folder.

                :param folder_id: The unique identifier that represent a folder.

        The ID for any folder can be determined
        by visiting this folder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/folder/123`
        the `folder_id` is `123`.
        Example: "12345"
                :type folder_id: str
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'fields': to_string(fields),
                'limit': to_string(limit),
                'marker': to_string(marker),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/folders/',
                        to_string(folder_id),
                        '/collaborations',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Collaborations)

    def get_collaborations(
        self,
        status: GetCollaborationsStatus,
        *,
        fields: Optional[List[str]] = None,
        offset: Optional[int] = None,
        limit: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> CollaborationsOffsetPaginated:
        """
                Retrieves all pending collaboration invites for this user.
                :param status: The status of the collaborations to retrieve.
                :type status: GetCollaborationsStatus
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param offset: The offset of the item at which to begin the response.

        Queries with offset parameter value
        exceeding 10000 will be rejected
        with a 400 response., defaults to None
                :type offset: Optional[int], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'status': to_string(status),
                'fields': to_string(fields),
                'offset': to_string(offset),
                'limit': to_string(limit),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/collaborations']
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, CollaborationsOffsetPaginated)

    def get_group_collaborations(
        self,
        group_id: str,
        *,
        limit: Optional[int] = None,
        offset: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> CollaborationsOffsetPaginated:
        """
                Retrieves all the collaborations for a group. The user

                must have admin permissions to inspect enterprise's groups.


                Each collaboration object has details on which files or


                folders the group has access to and with what role.

                :param group_id: The ID of the group.
        Example: "57645"
                :type group_id: str
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param offset: The offset of the item at which to begin the response.

        Queries with offset parameter value
        exceeding 10000 will be rejected
        with a 400 response., defaults to None
                :type offset: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'limit': to_string(limit), 'offset': to_string(offset)}
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/groups/',
                        to_string(group_id),
                        '/collaborations',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, CollaborationsOffsetPaginated)



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.schemas.v2025_r0.user_or_group_reference_v2025_r0 import (
    UserOrGroupReferenceV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError


class EnterpriseFeatureSettingV2025R0FeatureField(BaseObject):
    def __init__(self, *, id: Optional[str] = None, **kwargs):
        """
        :param id: The identifier of the feature., defaults to None
        :type id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id


class EnterpriseFeatureSettingV2025R0(BaseObject):
    def __init__(
        self,
        *,
        id: Optional[str] = None,
        feature: Optional[EnterpriseFeatureSettingV2025R0FeatureField] = None,
        state: Optional[str] = None,
        can_configure: Optional[bool] = None,
        is_configured: Optional[bool] = None,
        allowlist: Optional[List[UserOrGroupReferenceV2025R0]] = None,
        denylist: Optional[List[UserOrGroupReferenceV2025R0]] = None,
        **kwargs
    ):
        """
        :param id: The identifier of the enterprise feature setting., defaults to None
        :type id: Optional[str], optional
        :param feature: The feature., defaults to None
        :type feature: Optional[EnterpriseFeatureSettingV2025R0FeatureField], optional
        :param state: The state of the feature., defaults to None
        :type state: Optional[str], optional
        :param can_configure: Whether the feature can be configured., defaults to None
        :type can_configure: Optional[bool], optional
        :param is_configured: Whether the feature is configured., defaults to None
        :type is_configured: Optional[bool], optional
        :param allowlist: Enterprise feature setting is enabled for only this set of users and groups., defaults to None
        :type allowlist: Optional[List[UserOrGroupReferenceV2025R0]], optional
        :param denylist: Enterprise feature setting is enabled for everyone except this set of users and groups., defaults to None
        :type denylist: Optional[List[UserOrGroupReferenceV2025R0]], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.feature = feature
        self.state = state
        self.can_configure = can_configure
        self.is_configured = is_configured
        self.allowlist = allowlist
        self.denylist = denylist



from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.schemas.v2025_r0.file_reference_v2025_r0 import FileReferenceV2025R0

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.v2025_r0.doc_gen_template_base_v2025_r0 import (
    DocGenTemplateBaseV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.client_error_v2025_r0 import ClientErrorV2025R0

from box_sdk_gen.parameters.v2025_r0.box_version_header_v2025_r0 import (
    BoxVersionHeaderV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.doc_gen_template_create_request_v2025_r0 import (
    DocGenTemplateCreateRequestV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.doc_gen_templates_v2025_r0 import (
    DocGenTemplatesV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.doc_gen_template_v2025_r0 import DocGenTemplateV2025R0

from box_sdk_gen.schemas.v2025_r0.doc_gen_tags_v2025_r0 import DocGenTagsV2025R0

from box_sdk_gen.schemas.v2025_r0.doc_gen_tags_processing_message_v2025_r0 import (
    DocGenTagsProcessingMessageV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.doc_gen_jobs_v2025_r0 import DocGenJobsV2025R0

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class DocgenTemplateManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def create_docgen_template_v2025_r0(
        self,
        file: FileReferenceV2025R0,
        *,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> DocGenTemplateBaseV2025R0:
        """
        Marks a file as a Box Doc Gen template.
        :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
        :type box_version: BoxVersionHeaderV2025R0, optional
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'file': file}
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/docgen_templates']
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, DocGenTemplateBaseV2025R0)

    def get_docgen_templates_v2025_r0(
        self,
        *,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> DocGenTemplatesV2025R0:
        """
                Lists Box Doc Gen templates on which the user is a collaborator.
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'marker': to_string(marker), 'limit': to_string(limit)}
        )
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/docgen_templates']
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, DocGenTemplatesV2025R0)

    def delete_docgen_template_by_id_v2025_r0(
        self,
        template_id: str,
        *,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Unmarks file as Box Doc Gen template.
                :param template_id: ID of the file which will no longer be marked as a Box Doc Gen template.
        Example: "123"
                :type template_id: str
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/docgen_templates/',
                        to_string(template_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def get_docgen_template_by_id_v2025_r0(
        self,
        template_id: str,
        *,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> DocGenTemplateV2025R0:
        """
                Lists details of a specific Box Doc Gen template.
                :param template_id: The ID of a Box Doc Gen template.
        Example: 123
                :type template_id: str
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/docgen_templates/',
                        to_string(template_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, DocGenTemplateV2025R0)

    def get_docgen_template_tags_v2025_r0(
        self,
        template_id: str,
        *,
        template_version_id: Optional[str] = None,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> DocGenTagsV2025R0:
        """
                Lists all tags in a Box Doc Gen template.
                :param template_id: ID of template.
        Example: 123
                :type template_id: str
                :param template_version_id: Id of template version., defaults to None
                :type template_version_id: Optional[str], optional
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'template_version_id': to_string(template_version_id),
                'marker': to_string(marker),
                'limit': to_string(limit),
            }
        )
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/docgen_templates/',
                        to_string(template_id),
                        '/tags',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, DocGenTagsV2025R0)

    def get_docgen_template_job_by_id_v2025_r0(
        self,
        template_id: str,
        *,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> DocGenJobsV2025R0:
        """
                Lists the users jobs which use this template.
                :param template_id: Id of template to fetch jobs for.
        Example: 123
                :type template_id: str
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'marker': to_string(marker), 'limit': to_string(limit)}
        )
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/docgen_template_jobs/',
                        to_string(template_id),
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, DocGenJobsV2025R0)



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.folder_mini import FolderMini

from box_sdk_gen.schemas.file_mini import FileMini

from box_sdk_gen.schemas.resource import Resource

from box_sdk_gen.box.errors import BoxSDKError


class ResourceScopeScopeField(str, Enum):
    ANNOTATION_EDIT = 'annotation_edit'
    ANNOTATION_VIEW_ALL = 'annotation_view_all'
    ANNOTATION_VIEW_SELF = 'annotation_view_self'
    BASE_EXPLORER = 'base_explorer'
    BASE_PICKER = 'base_picker'
    BASE_PREVIEW = 'base_preview'
    BASE_UPLOAD = 'base_upload'
    ITEM_DELETE = 'item_delete'
    ITEM_DOWNLOAD = 'item_download'
    ITEM_PREVIEW = 'item_preview'
    ITEM_RENAME = 'item_rename'
    ITEM_SHARE = 'item_share'
    ITEM_UPLOAD = 'item_upload'
    ITEM_READ = 'item_read'


class ResourceScope(BaseObject):
    def __init__(
        self,
        *,
        scope: Optional[ResourceScopeScopeField] = None,
        object: Optional[Resource] = None,
        **kwargs
    ):
        """
        :param scope: The scopes for the resource access., defaults to None
        :type scope: Optional[ResourceScopeScopeField], optional
        """
        super().__init__(**kwargs)
        self.scope = scope
        self.object = object



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.shield_information_barrier_segment_restriction_base import (
    ShieldInformationBarrierSegmentRestrictionBaseTypeField,
)

from box_sdk_gen.schemas.shield_information_barrier_segment_restriction_base import (
    ShieldInformationBarrierSegmentRestrictionBase,
)

from box_sdk_gen.box.errors import BoxSDKError


class ShieldInformationBarrierSegmentRestrictionMiniShieldInformationBarrierSegmentTypeField(
    str, Enum
):
    SHIELD_INFORMATION_BARRIER_SEGMENT = 'shield_information_barrier_segment'


class ShieldInformationBarrierSegmentRestrictionMiniShieldInformationBarrierSegmentField(
    BaseObject
):
    _discriminator = 'type', {'shield_information_barrier_segment'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[
            ShieldInformationBarrierSegmentRestrictionMiniShieldInformationBarrierSegmentTypeField
        ] = None,
        **kwargs
    ):
        """
                :param id: The ID reference of the
        requesting shield information barrier segment., defaults to None
                :type id: Optional[str], optional
                :param type: The type of the shield information barrier segment., defaults to None
                :type type: Optional[ShieldInformationBarrierSegmentRestrictionMiniShieldInformationBarrierSegmentTypeField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class ShieldInformationBarrierSegmentRestrictionMiniRestrictedSegmentTypeField(
    str, Enum
):
    SHIELD_INFORMATION_BARRIER_SEGMENT = 'shield_information_barrier_segment'


class ShieldInformationBarrierSegmentRestrictionMiniRestrictedSegmentField(BaseObject):
    _discriminator = 'type', {'shield_information_barrier_segment'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[
            ShieldInformationBarrierSegmentRestrictionMiniRestrictedSegmentTypeField
        ] = None,
        **kwargs
    ):
        """
                :param id: The ID reference of the
        restricted shield information barrier segment., defaults to None
                :type id: Optional[str], optional
                :param type: The type of the shield information segment., defaults to None
                :type type: Optional[ShieldInformationBarrierSegmentRestrictionMiniRestrictedSegmentTypeField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class ShieldInformationBarrierSegmentRestrictionMini(
    ShieldInformationBarrierSegmentRestrictionBase
):
    def __init__(
        self,
        shield_information_barrier_segment: ShieldInformationBarrierSegmentRestrictionMiniShieldInformationBarrierSegmentField,
        restricted_segment: ShieldInformationBarrierSegmentRestrictionMiniRestrictedSegmentField,
        *,
        type: Optional[ShieldInformationBarrierSegmentRestrictionBaseTypeField] = None,
        id: Optional[str] = None,
        **kwargs
    ):
        """
                :param shield_information_barrier_segment: The `type` and `id` of the
        requested shield information barrier segment.
                :type shield_information_barrier_segment: ShieldInformationBarrierSegmentRestrictionMiniShieldInformationBarrierSegmentField
                :param restricted_segment: The `type` and `id` of the
        restricted shield information barrier segment.
                :type restricted_segment: ShieldInformationBarrierSegmentRestrictionMiniRestrictedSegmentField
                :param type: Shield information barrier segment restriction., defaults to None
                :type type: Optional[ShieldInformationBarrierSegmentRestrictionBaseTypeField], optional
                :param id: The unique identifier for the
        shield information barrier segment restriction., defaults to None
                :type id: Optional[str], optional
        """
        super().__init__(type=type, id=id, **kwargs)
        self.shield_information_barrier_segment = shield_information_barrier_segment
        self.restricted_segment = restricted_segment



from typing import Optional

from typing import Dict

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class MetadataTaxonomyLevel(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'display_name': 'displayName',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'displayName': 'display_name',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        *,
        display_name: Optional[str] = None,
        description: Optional[str] = None,
        level: Optional[int] = None,
        **kwargs
    ):
        """
        :param display_name: The display name of the level as it is shown to the user., defaults to None
        :type display_name: Optional[str], optional
        :param description: A description of the level., defaults to None
        :type description: Optional[str], optional
        :param level: An index of the level within the taxonomy. Levels are indexed starting from 1., defaults to None
        :type level: Optional[int], optional
        """
        super().__init__(**kwargs)
        self.display_name = display_name
        self.description = description
        self.level = level



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.file_full import FileFull

from box_sdk_gen.schemas.folder_full import FolderFull

from box_sdk_gen.schemas.web_link import WebLink

from box_sdk_gen.schemas.search_result_with_shared_link_item import (
    SearchResultWithSharedLinkItem,
)

from box_sdk_gen.box.errors import BoxSDKError


class SearchResultWithSharedLink(BaseObject):
    def __init__(
        self,
        *,
        accessible_via_shared_link: Optional[str] = None,
        item: Optional[SearchResultWithSharedLinkItem] = None,
        type: Optional[str] = None,
        **kwargs
    ):
        """
                :param accessible_via_shared_link: The optional shared link through which the user has access to this
        item. This value is only returned for items for which the user has
        recently accessed the file through a shared link. For all other
        items this value will return `null`., defaults to None
                :type accessible_via_shared_link: Optional[str], optional
                :param type: The result type. The value is always `search_result`., defaults to None
                :type type: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.accessible_via_shared_link = accessible_via_shared_link
        self.item = item
        self.type = type



from typing import Optional

from typing import Dict

from box_sdk_gen.schemas.file_base import FileBaseTypeField

from box_sdk_gen.schemas.file_base import FileBase

from box_sdk_gen.schemas.file_version_mini import FileVersionMini

from box_sdk_gen.box.errors import BoxSDKError


class FileMini(FileBase):
    _fields_to_json_mapping: Dict[str, str] = {
        'sha_1': 'sha1',
        **FileBase._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'sha1': 'sha_1',
        **FileBase._json_to_fields_mapping,
    }

    def __init__(
        self,
        id: str,
        *,
        sequence_id: Optional[str] = None,
        name: Optional[str] = None,
        sha_1: Optional[str] = None,
        file_version: Optional[FileVersionMini] = None,
        etag: Optional[str] = None,
        type: FileBaseTypeField = FileBaseTypeField.FILE,
        **kwargs
    ):
        """
                :param id: The unique identifier that represent a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
                :type id: str
                :param name: The name of the file., defaults to None
                :type name: Optional[str], optional
                :param sha_1: The SHA1 hash of the file. This can be used to compare the contents
        of a file on Box with a local file., defaults to None
                :type sha_1: Optional[str], optional
                :param etag: The HTTP `etag` of this file. This can be used within some API
        endpoints in the `If-Match` and `If-None-Match` headers to only
        perform changes on the file if (no) changes have happened., defaults to None
                :type etag: Optional[str], optional
                :param type: The value will always be `file`., defaults to FileBaseTypeField.FILE
                :type type: FileBaseTypeField, optional
        """
        super().__init__(id=id, etag=etag, type=type, **kwargs)
        self.sequence_id = sequence_id
        self.name = name
        self.sha_1 = sha_1
        self.file_version = file_version
